/*
 * ICacheStrategy.cs
 *
 * Copyright (c) 2004, TopCoder, Inc. All rights reserved.
 */
using System;

namespace TopCoder.Util.Idempotency.Strategy
{
    /// <summary>
    /// Interface for determining if requests should be cached or not in the <see cref="IdempotencyManager"/>.
    /// </summary>
    /// <remarks>
    /// <para>
    /// A component of this type is not required for the <see cref="IdempotencyManager"/> to run, but may
    /// be useful since it allows fine-grained control of which requests are cached and which are not.
    /// </para><para>
    /// This component currently provides a single implementation of this interface, the
    /// <see cref="TypeMappingCacheStrategy"/> class which allows requests to be filtered based on their type.
    /// </para><para>
    /// <B>NOTE:</B> Implementations of this interface should be thread-safe.
    /// </para>
    /// </remarks>
    /// <author>WishingBone</author>
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    public interface ICacheStrategy 
    {
        /// <summary>
        /// Determines if the given request should be cached or not.
        /// </summary>
        /// <param name="request">The request to determine if it should be cached.</param>
        /// <returns><B>true</B> if the request may be cached; otherwise, <B>false</B>.</returns>
        /// <exception cref="ArgumentNullException"><paramref name="request"/> is <B>null</B>.</exception>
        bool Accept(Request request);
    }
}
