/*
 * CacheEntryTests.cs
 *
 * Copyright (c) 2004, TopCoder, Inc. All rights reserved.
 */
using System;
using NUnit.Framework;

namespace TopCoder.Util.Idempotency
{
    /// <summary>
    /// Tests of the <see cref="CacheEntry"/> class.
    /// </summary>
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    [TestFixture]
    public class CacheEntryTests
    {
        /// <summary>
        /// Test the construtor to make sure it sets the instance fields correctly.
        /// </summary>
        [Test]
        public void TestCtor2()
        {
            DateTime time = DateTime.Now;
            CacheEntry ce = new CacheEntry(time, true);

            Assert.AreEqual(time, ce.LastActivity, "Wrong activity time set.");
            Assert.IsTrue(ce.IsInStorage, "Wrong storage value set.");
        }

        /// <summary>
        /// Test getting and setting the LastActivity time.
        /// </summary>
        [Test]
        public void TestLastActivity()
        {
            DateTime t1 = DateTime.Now;
            DateTime t2 = DateTime.MaxValue;

            CacheEntry ce = new CacheEntry(t1, false);

            Assert.AreEqual(t1, ce.LastActivity, "Wrong activity time set.");
            
            ce.LastActivity = t2;

            Assert.AreEqual(t2, ce.LastActivity, "Activity time not changed.");
        }

        /// <summary>
        /// Test getting and setting the IsInStorage property.
        /// </summary>
        [Test]
        public void TestIsInStorage()
        {
            CacheEntry ce = new CacheEntry(DateTime.Now, false);

            Assert.IsFalse(ce.IsInStorage, "Wrong storage value set.");

            ce.IsInStorage = true;

            Assert.IsTrue(ce.IsInStorage, "Storage value not changed.");
        }
    }
}
