/*
 * PersistenceExceptionTests.cs
 *
 * Copyright (c) 2004, TopCoder, Inc. All rights reserved.
 */
using System;
using NUnit.Framework;

namespace TopCoder.Util.Idempotency.Persistence
{
    /// <summary>
    /// Tests of the <see cref="PersistenceException"/> class.
    /// </summary>
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    [TestFixture]
    public class PersistenceExceptionTests
    {
        /// <summary>
        /// Calling the 1-arg constructor with a null message should throw an ANE.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentNullException))]
        public void TestCtor1NullArg()
        {
            new PersistenceException(null);
        }

        /// <summary>
        /// Calling the 1-arg constructor with an empty message should throw an AE.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentException))]
        public void TestCtor1EmptyArg()
        {
            new PersistenceException("");
        }

        /// <summary>
        /// Calling the 1-arg constructor with a valid message should work just fine.
        /// </summary>
        [Test]
        public void TestCtor1()
        {
            Exception e = new PersistenceException("message");

            Assert.AreEqual("message", e.Message, "The message is wrong.");
            Assert.IsNull(e.InnerException, "The inner exception should not be set.");
        }

        /// <summary>
        /// Calling the 2-arg constructor with a null message should throw an ANE.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentNullException))]
        public void TestCtor2NullArg()
        {
            new PersistenceException(null, new Exception());
        }

        /// <summary>
        /// Calling the 2-arg constructor with an empty message should throw an AE.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentException))]
        public void TestCtor2EmptyArg()
        {
            new PersistenceException("", new Exception());
        }

        /// <summary>
        /// Calling the 2-arg constructor with a null cause should throw an ANE.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentNullException))]
        public void TestCtor2NullArg2()
        {
            new PersistenceException("message", null);
        }

        /// <summary>
        /// Calling the 2-arg constructor with valid parameters should work just fine.
        /// </summary>
        [Test]
        public void TestCtor2()
        {
            Exception inner = new Exception();
            Exception e = new PersistenceException("message", inner);

            Assert.AreEqual("message", e.Message, "The message is wrong.");
            Assert.AreSame(inner, e.InnerException, "The inner exception is wrong.");
        }
    }
}
