/*
 * ResponseRerievalExceptionTests.cs
 *
 * Copyright (c) 2004, TopCoder, Inc. All rights reserved.
 */
using System;
using NUnit.Framework;

namespace TopCoder.Util.Idempotency.Persistence
{
    /// <summary>
    /// Tests of the <see cref="ResponseRetrievalException"/> class.
    /// </summary>
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    [TestFixture]
    public class ResponseRetrievalExceptionTests
    {
        /// <summary>
        /// Calling the constructor with a null Request should cause an ANE to be thrown.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentNullException))]
        public void TestCtor1NullArg()
        {
            new ResponseRetrievalException(null);
        }

        /// <summary>
        /// Create a new exception with a valid request and validate its Reqeust property and Message values.
        /// </summary>
        [Test]
        public void TestCtor()
        {
            // Create a test request and then use it to create the exception.
            Request request = new Request("id", "key", "type");

            ResponseRetrievalException e = new ResponseRetrievalException(request);

            // Make sure the values were set properly.
            Assert.AreSame(request, e.Request, "The request object is not the same.");
            Assert.AreEqual("Unable to retrieve a response for this request: " + request.Identifier,
                e.Message, "The error message is incorrect.");
        }
    }
}
