/*
 * RequestTests.cs
 *
 * Copyright (c) 2004, TopCoder, Inc. All rights reserved.
 */
using System;
using NUnit.Framework;

namespace TopCoder.Util.Idempotency
{
    /// <summary>
    /// Tests of the <see cref="Request"/> class.
    /// </summary>
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    [TestFixture]
    public class RequestTests
    {
        /// <summary>
        /// Calling the 2-arg constructor with a null ID should throw an ANE.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentNullException))]
        public void TestCtor2Arg1Null()
        {
            new Request(null, "key");
        }

        /// <summary>
        /// Calling the 2-arg constructor with an empty ID should throw an AE.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentException))]
        public void TestCtor2ArgEmpty()
        {
            new Request("", "key");
        }

        /// <summary>
        /// Calling the 2-arg constructor with a null security key should throw an ANE.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentNullException))]
        public void TestCtor2Arg2Null()
        {
            new Request("id", null);
        }

        /// <summary>
        /// Calling the 2-arg constructor with valid parameters should set the instance fields properly.
        /// </summary>
        [Test]
        public void TestCtor2()
        {
            Request r = new Request("id", "");

            Assert.AreEqual("id", r.Identifier, "Wrong identifier.");
            Assert.AreEqual("", r.SecurityKey, "Wrong security key.");
            Assert.AreEqual("", r.Type, "Wrong type.");
        }

        /// <summary>
        /// Calling the 3-arg constructor with a null ID should throw an ANE.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentNullException))]
        public void TestCtor3Arg1Null()
        {
            new Request(null, "key", "type");
        }

        /// <summary>
        /// Calling the 3-arg constructor with an empty ID should throw an AE.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentException))]
        public void TestCtor3ArgEmpty()
        {
            new Request("", "key", "type");
        }

        /// <summary>
        /// Calling the 3-arg constructor with a null security key should throw an ANE.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentNullException))]
        public void TestCtor3Arg2Null()
        {
            new Request("id", null, "type");
        }

        /// <summary>
        /// Calling the 3-arg constructor with a null type should throw an ANE.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentNullException))]
        public void TestCtor3Arg3Null()
        {
            new Request("id", "key", null);
        }

        /// <summary>
        /// Calling the 3-arg constructor with valid parameters should set the instance fields properly.
        /// </summary>
        [Test]
        public void TestCtor3()
        {
            Request r = new Request("id", "key", "type");

            Assert.AreEqual("id", r.Identifier, "Wrong identifier.");
            Assert.AreEqual("key", r.SecurityKey, "Wrong security key.");
            Assert.AreEqual("type", r.Type, "Wrong type.");
        }
    }
}
